@@ -15,8 +15,8 @@ urlpatterns = patterns('',
     url(r'^simple/', include('localshop.packages.urls_simple',
         namespace='packages-simple')),
 
-    url(r'^accounts/',
-        include('localshop.accounts.urls', namespace='accounts')),
+    url(r'^permissions/',
+        include('localshop.permissions.urls', namespace='permissions')),
 
     url(r'^admin/', include(admin.site.urls)),
 
